@@ -187,6 +187,48 @@ class WrappedAnonymizer(SupervisedLearningAnonymizer):
             )
 
 
+class TFKerasWrapper(SupervisedLearningAnonymizer):
+    """If you already have a compiled (!) model of type `tf.keras.layers.Model`,
+    use this wrapper to lift it no the `SupervisedLearningAnonymizer` interface.
+    """
+
+    def __init__(
+        self,
+        tfkeras_model: Any,
+        feature_array_validator: Callable[[np.ndarray], None],
+        **kwargs,
+    ) -> None:
+        """
+        Parameters
+        ----------
+        tfkeras_model : tf.keras.layers.Model
+            A compiled (!) model created using tf.keras.
+        feature_array_validator : Callable[[np.ndarray], None]
+            The function to use, when invoking
+            `SupervisedLearningAnonymizer.validate_input` (see the abstract
+            class' docs for more info).
+        **kwargs : dict[str, Any]
+            Further arguments that will be passed to `tfkeras_model.fit`. Avoid
+            setting the parameters `x` and `y`, as they are already in use by
+            this wrapper.
+        """
+        self._model = tfkeras_model
+        self._feature_array_validator = feature_array_validator
+        self._additional_fit_params = kwargs
+
+    def fit(self, X: np.ndarray, y: np.ndarray) -> None:
+        return self._model.fit(x=X, y=y, **self._additional_fit_params)
+
+    def predict(self, X: np.ndarray, batch_size: int | None = None) -> np.ndarray:
+        return self._model.predict(x=X, batch_size=batch_size)
+
+    def save(self, filepath: str | Path) -> None:
+        return self._model.save(filepath=filepath)
+
+    def validate_input(self, feature_array: np.ndarray) -> None:
+        self._feature_array_validator(feature_array)
+
+
 def pickle_anonymizer(anonymizer: Any, filepath: str | Path) -> None:
     """A pickling-based serializer to use as a replacement in
     `WrappedAnonymizer`"""
