@@ -139,6 +139,42 @@ def test_raising_WrappedAnonymizer(
         )
 
 
+def test_TFKerasWrapper(ten_elem_ndarray, tmp_path):
+    tfkeras = pytest.importorskip("tf_keras")
+    model = tfkeras.Sequential(
+        [
+            tfkeras.layers.Input(shape=(1,)),
+            tfkeras.layers.Dense(10, activation="relu"),
+            tfkeras.layers.Dense(1, activation="relu"),
+        ]
+    )
+    model(ten_elem_ndarray)
+    model.compile(
+        optimizer="adam",
+        loss="mse",
+        metrics=[tfkeras.metrics.MeanAbsoluteError(name="mean_absolute_error")],
+    )
+
+    additional_fit_args = dict(epochs=3)
+
+    wrapped_model = anonymizer.TFKerasWrapper(
+        tfkeras_model=model,
+        feature_array_validator=dummy_validation_function,
+        **additional_fit_args,
+    )
+    p = tmp_path / "model.keras"
+    wrapped_model.save(p)
+    saved_model = anonymizer.TFKerasWrapper(
+        tfkeras_model=tfkeras.models.load_model(p),
+        feature_array_validator=dummy_validation_function,
+        **additional_fit_args,
+    )
+    for anon in [wrapped_model, saved_model]:
+        anon.fit(X=ten_elem_ndarray, y=ten_elem_ndarray)
+        anon.predict(ten_elem_ndarray)
+        anon.validate_input(ten_elem_ndarray)
+
+
 def test_batch_views(empty_ndarray: np.ndarray, ten_elem_ndarray: np.ndarray):
     [batch] = anonymizer._batch_views(empty_ndarray, 0)
     assert len(batch) == 0
